# This file is managed by /Users/kitahara-so/perl5/perlbrew/perls/perl-5.14.2/bin/dim.
{
  dist => 'Test::Deep::Teng::Row',
  distdir => 'Test-Deep-Teng-Row',
  module => 'Test::Deep::Teng::Row',
  template => 'Default'
}
